@@ -160,9 +160,9 @@ class RedisForeignKey(RedisNumber):
         instance = {
             'id': id
         }
-        for key in redis_root.redis_instance.scan_iter(f'{redis_root.prefix}:{model_name}:{id}:*'):
+        fast_get_results = redis_root.fast_get_keys_values(f'{redis_root.prefix}:{model_name}:{id}:*')
+        for key, raw_value in fast_get_results.items():
             prefix, model_name, instance_id, field_name = key.split(':')
-            raw_value = redis_root.redis_instance.get(key)
             value = redis_root.deserialize_value(raw_value, model_name, field_name)
             instance[field_name] = value
         return instance
@@ -257,9 +257,9 @@ class RedisManyToMany(RedisList):
         instance = {
             'id': id
         }
-        for key in redis_root.redis_instance.scan_iter(f'{redis_root.prefix}:{model_name}:{id}:*'):
+        fast_get_results = redis_root.fast_get_keys_values(f'{redis_root.prefix}:{model_name}:{id}:*')
+        for key, raw_value in fast_get_results.items():
             prefix, model_name, instance_id, field_name = key.split(':')
-            raw_value = redis_root.redis_instance.get(key)
             value = redis_root.deserialize_value(raw_value, model_name, field_name)
             instance[field_name] = value
         return instance
@@ -590,6 +590,12 @@ class RedisRoot:
             )
             print(f'Cached {django_model}')
 
+    def fast_get_keys_values(self, string):
+        keys = self.redis_instance.scan_iter(string)
+        values = self.redis_instance.mget(keys)
+        results = dict(zip(keys, values))
+        return results
+
     def _get_connection_pool(self, connection_pool):
         if isinstance(connection_pool, redis.ConnectionPool):
             connection_pool.connection_kwargs['decode_responses'] = True
@@ -832,10 +838,10 @@ class RedisRoot:
     def _get_all_stored_model_instances(self, model, filters=None):
         model_name = model.__name__
         instances_with_allowed = {}
-        for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:*'):
+        fast_get_results = self.fast_get_keys_values(f'{self.prefix}:{model_name}:*')
+        for key, raw_value in fast_get_results:
             prefix, model_name, instance_id, field_name = key.split(':')
             instance_id = int(instance_id)
-            raw_value = self.redis_instance.get(key)
             value = self.deserialize_value(raw_value, model_name, field_name)
             allowed = self._filter_field_name(field_name, value, filters)
             if instance_id not in instances_with_allowed.keys():
